@@ -11,6 +11,8 @@
 #'   (must a continuous vector).
 #' @param explanatory Character vector of any length: name(s) of explanatory
 #'   variables.
+#' @param weights Character vector of length 1: name of variabe for weighting. 
+#' 'Prior weights' to be used in the fitting process.
 #' @param ... Other arguments to pass to \code{\link[stats]{lm}}.
 #' @return A multivariable \code{\link[stats]{lm}} fitted model.
 #'
@@ -29,8 +31,10 @@
 #'   lmmulti(dependent, explanatory) %>%
 #'   fit2df()
 #' 
-lmmulti <- function(.data, dependent, explanatory, ...){
-  ff_eval(
-    lm(ff_formula(dependent, explanatory), data = .data, ...)
-  )
+lmmulti <- function(.data, dependent, explanatory, weights = "", ...){
+	result = ff_eval(
+		lm(ff_formula(dependent, explanatory), data = .data, weights = !!sym(weights), ...)
+	)
+	result$call$formula = formula(result)
+	return(result)
 }
